#
# spec file for package okular
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang

Name:           okular
Version:        17.12.3
Release:        lp150.5.1
%define kf5_version 5.26.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %global _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
Summary:        Document Viewer
# GPL-3.0+ license used by a runtime plugin
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Office/Other
Url:            http://www.kde.org
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-path-traversal-issue-when-extracting-an-.okular-.patch
BuildRequires:  chmlib-devel
BuildRequires:  extra-cmake-modules
BuildRequires:  freetype2-devel
BuildRequires:  kactivities5-devel
BuildRequires:  karchive-devel
BuildRequires:  kbookmarks-devel
BuildRequires:  kcompletion-devel
BuildRequires:  kconfig-devel
BuildRequires:  kconfigwidgets-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  kdbusaddons-devel
BuildRequires:  kdoctools-devel
BuildRequires:  kf5-filesystem
BuildRequires:  khtml-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kio-devel
BuildRequires:  kjs-devel
BuildRequires:  kparts-devel
BuildRequires:  kpty-devel
BuildRequires:  kwallet-devel
BuildRequires:  kwindowsystem-devel
BuildRequires:  libdjvulibre-devel
BuildRequires:  libepub-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libkexiv2-devel
BuildRequires:  libmarkdown-devel
BuildRequires:  libpoppler-qt5-devel
BuildRequires:  libqca-qt5-devel
BuildRequires:  libspectre-devel
BuildRequires:  libtiff-devel
BuildRequires:  libzip-devel
BuildRequires:  mobipocket-devel
BuildRequires:  phonon4qt5-devel
BuildRequires:  pkgconfig
BuildRequires:  purpose-devel
BuildRequires:  threadweaver-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt5Core) >= 5.6.0
BuildRequires:  pkgconfig(Qt5DBus) >= 5.6.0
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Qml) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Quick) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Svg) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.6.0
BuildRequires:  pkgconfig(Qt5TextToSpeech)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.6.0
Obsoletes:      okular5 < %{version}
Provides:       okular5 = %{version}
%if %{with lang}
Recommends:     %{name}-lang
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Document viewing program; supports document in PDF, PS and
many other formats.

%package devel
Summary:        Document Viewer - Development Files
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       cmake(KF5Config)
Requires:       cmake(KF5CoreAddons)
Requires:       cmake(KF5XmlGui)
Requires:       cmake(Qt5Core) >= 5.6.0
Requires:       cmake(Qt5PrintSupport) >= 5.6.0
Requires:       cmake(Qt5Widgets) >= 5.6.0
Obsoletes:      okular5-devel < %{version}
Provides:       okular5-devel = %{version}

%description devel
Document viewing program; supports document in various formats

%if %{with lang}
%lang_package
%endif

%prep
%setup -q -n okular-%{version}
%autopatch -p1

%build
%cmake_kf5 -d build
%make_jobs

%install
%make_install -C build
%if %{with lang}
  %find_lang %{name} --with-man --all-name
  %kf5_find_htmldocs
%endif

rm -rfv %{buildroot}/%{_kf5_applicationsdir}/org.kde.mobile*

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING*
%config %{_kf5_configdir}/okular.categories
%dir %{_kf5_appstreamdir}
%dir %{_kf5_htmldir}
%dir %{_kf5_htmldir}/en
%doc %lang(en) %{_kf5_htmldir}/en/*/
%doc %{_kf5_mandir}/man1/okular.*
%{_kf5_sharedir}/kpackage/
%{_kf5_applicationsdir}/*.desktop
%{_kf5_appstreamdir}/org.kde.okular*.xml
%{_kf5_bindir}/okular
%{_kf5_configkcfgdir}/
%{_kf5_iconsdir}/hicolor/*/*/okular.*
%{_kf5_kxmlguidir}/
%{_kf5_libdir}/libOkular5Core.so.*
%{_kf5_plugindir}/
%{_kf5_qmldir}/
%{_kf5_servicesdir}/
%{_kf5_servicetypesdir}/
%{_kf5_sharedir}/kconf_update
%{_kf5_sharedir}/okular

%files devel
%defattr(-,root,root)
%doc COPYING*
%{_kf5_cmakedir}/Okular5/
%{_kf5_libdir}/libOkular5Core.so
%{_kf5_prefix}/include/okular/

%if %{with lang}
%files lang -f %{name}.lang
%doc COPYING*
%endif

%changelog
* Mon Sep 10 2018 Luca Beltrame <lbeltrame@kde.org>
- Add patch 0001-Fix-path-traversal-issue-when-extracting-an-.okular-.patch:
  * Fix directory traversal issue with .okular files (kde#398096,
  boo#1107591,rh#1626265, CVE-2018-1000801)
* Tue Mar 27 2018 wbauer@tmo.at
- Add some build requirements to enable additional features:
  * Qt5TextToSpeech for text-to-speech support
  * purpose-devel for enabling the share menu
  * libmarkdown-devel for displaying Markdown documents
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Add QVERIFY to QTest::qWaitForWindowExposed
  * Fix crash due to dangling pointer in MouseAnnotation (kde#388228)
  * Build++
  * Add test that produces bug 388288 crash
  * Make it compile
  * Make Part::openUrl not discard OpenUrlArguments (kde#386600)
  * Fix potential crash in document saving
  * PDF: Fix potential crash
  * XPS: Fix crash opening some files
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Add pdf.gz file save test
  * Fix saving annotations to gzipped files (kde#338742)
  * Fix crash on save when we had edited forms
  * parttest: make the mouse selection be a few steps
  * Use correct arrow cursor for Annotations' close buttons (kde#384381)
  * Improve parttest a bit
  * Fix regression due to more QTemporaryFile behaviour changes
  * Fix crash when exporting
  * djvu: Fix printing
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * remove deprecated Encoding key from desktop files
  * Fix testSaveAsUndoStackAnnotations autotest
  * Don't call m_formsMessage->setVisible( true ) on unsetDummyMode
* Tue Dec 12 2017 lbeltrame@kde.org
- Adjust license after legal review
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Fix crash when accessing text page after save
  * Unbreak compilation of the chm backend
  * We broke ABI by adding a new virtual to generator
  * Increase version now that we're not on unstable versioning anymore
  * Enable -DQT_NO_URL_CAST_FROM_STRING and fix compilation
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Prevent Okular from crashing when synctex logs an error (kde#383915)
  * Change whitespace in synctex patches
  * Fix highlight/annotation clipping with Qt scaling (kde#386110)
  * Give warnings when the file is modified externally
  * generators: Use a specific description for libzip
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Fix crash on rotation jobs
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Show tooltip for annotations without handle too
  * Properly create KPixmapSequence
  * Fix sidebar labels being unreadable when selected or hovered over (kde#382139)
  * Fix automatic reload of files saved with QSaveFile (kde#384185)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Search for Kirigami
  * CMake: Use some more find_package(... CONFIG)
  * Do not start reloading again if we're reloading
  * Fix crash when closing
  * Fix warning about TRANSLATION_DOMAIN being defined twice
  * Add the base .arcconfig file
  * Fix translations: add translation domain for generators
  * Fix memory leak in text document settings d-pointers
  * Fix width and height being switched when printing Custom size
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * plucker: Comment code to reduce warnings
  * Add a few make gcc lines
  * Fix small warning
  * Make newer gcc happier about fallthrough
  * Add missing break to switch case
  * Fix warning in newer gcc versions
  * 1.2.x for KDE Applications 17.08.x
  * port to Kirigami 2
  * Support Forward and Backward mouse buttons in presentation mode
  * Simplify method FilePrinter::psPaperSize
  * Minor
  * Bug 236688 - Sort pages according to TOC in CHM Files
  * CHM: zooming changes the font size
  * Bug 262265 chmlib should not send qFatal if encoding could not be guessed
  * kio_msits emits mimetype again
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.07.90.php
* Sun Jul 16 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Shell: Fix sync "Show menubar" action status
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Initialize cursor in PageView scrollbars with ArrowCursor (kde#334798)
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Don't repeat work of KAboutData::setApplicationData(), set window icon
  * Fix typo
  * Drop unused DBusAddons
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Fix segfault when document is closed while annotation is selected
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * cmake: Remove endif that doesn't match opening if
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.03.80.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * djvu: Initialize to white if rendering fails
  * indent++
  * Accumulate Control+Wheel Deltas until they reach QWheelEvent::DefaultDeltasPerStep
  * Fix crash on CHM files that use "plain English" LCID
  * Account for non local non relative video file urls
  * Extend viewport update area when updating or clearing the a selection rectangle (kde#266537)
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Thu Jan 19 2017 wbauer@tmo.at
- Cleanup/update build requirements
- Add necessary dependencies to the devel package (boo#1020735)
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
- Dropped patches:
  + fix-priority-okular.diff
  + kde4_includes.patch
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
- Drop upstreamed patch mimeinfo17.patch
* Sat Oct  1 2016 wbauer@tmo.at
- Add mimeinfo17.patch to fix opening CBR files with
  shared-mime-info 1.7 (kde#369078)
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.07.90.php
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Mon Jun 27 2016 fvogt@suse.com
- Fix copying of oxygen icons
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Thu Sep 24 2015 alarrosa@suse.com
- Added libqjson-devel to buildrequires
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Mon Aug 10 2015 wbauer@tmo.at
- Replace pkgconfig(exiv2) BuildRequires with pkgconfig(libkexiv2).
  Okular needs to be built against libkexiv2 for image support
  (kimgio plugin), not exiv2.
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.07.90.php
* Fri Jul 24 2015 nemysis@gmx.ch
- Change URL
- Change Source0 Web URL that works 'osc service localrun download_files'
- Use BuildRequires pkgconfig() instead of devel packages
- Change Description for okular-devel
- Use %%{name} instead of okular
- Change Documentation
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Aug 14 2014 hrvoje.senjan@gmail.com
- Added kde4_includes.patch: search for includes in standard kde4
  include directory (don't assume it's hardcoded to include/ )
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Thu May  1 2014 hrvoje.senjan@gmail.com
- Added libkscreen-devel BuildRequires, so DPI of current screen
  is used for PDF rendering
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
- Added libkexiv2-devel and mobipocket-devel BuildRequires
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
- Dropped okularcolorbackports.diff, included in this release
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Feb 14 2013 wstephenson@suse.com
- Fix dark-on-dark colour bug when using dark colour schemes
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan 10 2013 tittiatcoke@gmail.com
- Add patch fix-priority-okular.diff to ensure that Okular always
  has a higher priority than the active-documentviewer.
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sun Nov 25 2012 tittiatcoke@gmail.com
- Drop patch 4_8_branch.diff as it is not used at all
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
- remove upstreamed patch
- add empty 4_8_BRANCH.diff that can be refreshed later
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Fri Nov 11 2011 ctrippe@opensuse.org
- Fix printing with landscape layout (bnc#625122)
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Sat Oct  8 2011 toddrme2178@gmail.com
- Added provides for obsoletes (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Mon Sep  5 2011 mlin@suse.com
- add %%fdupes for files duplicated(fix for RPMLINT warnings)
- clean up the specfile format
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Mon Aug  8 2011 mlin@suse.com
- Fixed group for devel package (fix for RPMLINT warning)
- Do not need add standard hierarchy directory: /usr/include in
  files list (fix for RPMLINT warning)
- Use %%{_includedir} macro instead of absolute path /usr/include
- Add version of the dependency requirement for devel package
  (fix for RPMLINT warning)
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Sat Jul  9 2011 dmueller@suse.de
- update to 4.6.95
* Mon Jul  4 2011 idonmez@novell.com
- Update to 4.6.90
* Tue Jun 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110621
* Mon Jun 20 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110620
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Wed Jun 15 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110615
* Tue Jun 14 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110614
* Mon Jun 13 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110613
* Sun Jun 12 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110612
* Sat Jun 11 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110611
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Mon Jun  6 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110606
* Sun Jun  5 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110605
* Sat Jun  4 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110604
* Fri Jun  3 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110603
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Wed Jun  1 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110601
* Wed Jun  1 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110601
* Tue May 31 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110531
* Mon May 30 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110530
* Sat May 28 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110528
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Wed May 25 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110525
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Mon May 23 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110523
* Sat May 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110521
* Fri May 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110520
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Wed May 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110518
* Tue May 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110517
* Mon May 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110516
* Sun May 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110515
* Sat May 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110514
* Fri May 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110513
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Wed May 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110511
* Tue May 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110510
* Mon May  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110509
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Sat May  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110507
* Fri May  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110506
* Thu May  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110505
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Tue May  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110503
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110430
* Fri Apr 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110429
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Fri Apr 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110422
* Thu Apr 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110421
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Tue Apr 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110419
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sat Apr 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110416
* Fri Apr 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110415
* Thu Apr 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110414
* Wed Apr 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110413
* Tue Apr 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110412
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110411
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to .._20110411
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sat Apr  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110409
* Fri Apr  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110408
* Thu Apr  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110407
* Wed Apr  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110406
* Tue Apr  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110405
* Mon Apr  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110404
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Wed Jan  5 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Wed Sep 15 2010 aj@suse.de
- Change BuildRequires for sane-backends devel split.
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Sat Feb 20 2010 dmueller@suse.de
- tighten library version requires
* Tue Feb  9 2010 dmueller@suse.de
- relax poppler version requirement for more flexibility in
  maintenance updates
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Fri Jan  8 2010 ro@suse.de
- remove imlib from buildrequires (unused)
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Tue Oct 13 2009 beineri@opensuse.org
- only recommend unrar (bnc#546188)
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: translation updates and gwenview fixes
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Thu Aug 20 2009 beineri@opensuse.org
- gwenview: don't let Photography category sneak in from upstream
* Sun Aug 16 2009 beineri@opensuse.org
- remove kolourpaint from Utilities/Editor/ start menu category
* Fri Aug  7 2009 llunak@novell.com
- solid action when pluggin in camera (bnc#505997)
* Thu Aug  6 2009 llunak@suse.cz
- branch update (bnc#528731)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Wed Jul 22 2009 llunak@suse.cz
- epub dependency for okular (bnc#512631)
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Wed Jul  8 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu May 14 2009 dmueller@suse.de
- add versioned deps
* Sun May  3 2009 beineri@opensuse.org
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Tue Apr 21 2009 dmueller@suse.de
- rename kde4-gwenview -> gwenview
* Mon Apr 20 2009 dmueller@suse.de
- rename libkexiv2-7-devel to libkexiv2-devel
- rename libkdcraw7-devel to libkdcraw-devel
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Wed Mar 18 2009 dmueller@suse.de
- 4_2_BRANCH.diff:
  * fix gwenview version number
* Tue Mar 10 2009 wstephenson@suse.de
- Add fixed version dependency on libpoppler-qt4-3 to kde4-okular
  to ensure the latest version of libpoppler is installed
  (kde#483753)
* Sat Feb 28 2009 dmueller@suse.de
- build against libqca2 for encrypted document support in okular
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Wed Feb 18 2009 dmueller@suse.de
- update branch diff
* Wed Feb  4 2009 stbinner@suse.de
- require unrar for Okular comic book plugin (bnc#467204)
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Wed Jan 21 2009 stbinner@suse.de
- split off libksane-devel sub-package
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Mon Jan 12 2009 dmueller@suse.de
- rename libkipi6-devel to libkipi-devel
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Fri Nov 28 2008 dmueller@suse.de
- update libkexiv/libkdcraw to trunk for beta6 of digikam
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Wed Nov  5 2008 dmueller@suse.de
- update libkexiv2 / libkdcraw diffs for kde4-digikam
* Tue Nov  4 2008 dmueller@suse.de
- update tarball to final version
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Tue Oct 21 2008 stbinner@suse.de
- branch diff update: gwenview and okular bug fix backports
* Wed Oct  1 2008 dmueller@suse.de
- replace tarball, add libkdcraw upgrade patch to get the same
  code state like before
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Sat Sep 20 2008 stbinner@suse.de
- fix packaging of libksane includes
* Tue Sep  9 2008 dmueller@suse.de
- branch diff update (includes libdcraw6 update for kde4-digikam)
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Tue Aug 19 2008 stbinner@suse.de
- branch diff update: several Okular fixes
* Wed Jul 30 2008 dmueller@suse.de
- update branch diff to fix okular print preview
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Thu Jul 17 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Mon Jul  7 2008 dmueller@suse.de
- update to 4.0.85
* Tue Jul  1 2008 dmueller@suse.de
- fix clashing -devel packages
* Mon Jun 30 2008 dmueller@suse.de
- fix filelist
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Fri Apr 25 2008 dmueller@suse.de
- branch diff update
- fix file lists
* Mon Apr 14 2008 dmueller@suse.de
- fix postscript support (bnc#366514)
* Mon Apr  7 2008 dmueller@suse.de
- add qca2 to buildrequires
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update 4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Sat Dec  8 2007 dmueller@suse.de
- update to 3.97.0
* Sat Dec  8 2007 stbinner@suse.de
- fix build
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Thu Oct 18 2007 dmueller@suse.de
- update to 3.94.1
* Thu Oct 11 2007 sbrabec@suse.cz
- poppler devel package names prepended by "lib".
* Tue Oct  9 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  9 2007 sbrabec@suse.cz
- Fixed typo in SuSE version check in previous change.
* Mon Oct  8 2007 sbrabec@suse.cz
-  Use binding specific poppler devel package.
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720248
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Fri Sep 21 2007 stbinner@suse.de
- fix gwenview.desktop mime-type definition / SUSEconfig warning
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712063
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703909
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700760
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
* Sat Jul 28 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685968
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn678982
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Mon May 28 2007 dmueller@suse.de
- update to 3.90.1.svn668119
* Fri May 25 2007 stbinner@suse.de
- split off -devel package
* Fri May 18 2007 stbinner@suse.de
- initial package in abuild
